function [nodes_or_indices, empty_output] = entryId_useall(N, d, basis_types, return_type)
%ENTRYID_USEALL skips entry identifications and returns all possible indices.
%  Supports all basis types.
%
%  Input:
%    N - scalar, number of possible basis indices per spatial dimension
%        (side length of cube)
%    d - scalar, spatial dimension
%    basis_types - cell array of length d
%    return_type - either 'nodes' or indices', determines output variables,
%                  'nodes' returns pairing grids, 'indices' performs pairing
%
%  Output:
%    nodes_or_indices - for return_type='nodes': cell array of length d
%                       containing double matrix: 0 \times d,
%                       for return_type='indices': cell array of length d
%                       containing column vector of all possible basis indices
%    empty_output - empty matrix
%
% version with speed improvements and generalizations 2018-2019 by Toni Volkmer

switch return_type
  case 'nodes'
    nodes_or_indices = cell(d,1);
    for j=1:d
      nodes_or_indices{j} = zeros(0,d);
    end
    empty_output = [];
  case 'indices'
    nodes_or_indices = cell(d,1);
    empty_output = [];
    for j=1:d
      nodes_or_indices{j} = (0:N-1)';
    end
  otherwise
    error('Unknown return_type: %s', return_type);
end

end
